"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const axios_1 = require("axios");
const fs = require("fs");
const writeFile = function (file, data) {
    data = JSON.stringify(data);
    return new Promise((res, rej) => {
        fs.writeFile(file, data, (err) => {
            if (err) {
                return rej(err);
            }
            return res();
        });
    });
};
class SpringCloudConfigClient {
    constructor(option) {
        this.option = option;
        let requestOption = {};
        requestOption.baseURL = this.option.configServerUrl;
        if (option.auth) {
            requestOption.auth = {
                username: this.option.auth.username,
                password: this.option.auth.password,
            };
        }
        this.request = axios_1.default.create(requestOption);
    }
    async fetch(applicationProfile) {
        let name = this.option.name;
        let profile = this.option.profile;
        if (applicationProfile) {
            name = applicationProfile.name;
            profile = applicationProfile.profile;
        }
        let url = name;
        if (profile) {
            url += `-${profile}`;
        }
        url += '.json';
        try {
            const result = await this.request.get(url);
            return result.data;
        }
        catch (e) {
            throw e;
        }
    }
    async write(absolutFilePath, applicationProfile) {
        try {
            const data = await this.fetch(applicationProfile);
            await writeFile(absolutFilePath, data);
            return data;
        }
        catch (e) {
            throw e;
        }
    }
}
exports.default = SpringCloudConfigClient;
//# sourceMappingURL=index.js.map